package jj::rtf;
$VERSION = "0.001";
# http://latex2rtf.sourceforge.net/RTF-Spec-1.0.txt
# http://en.wikipedia.org/wiki/Rich_Text_Format
# Flygande bckasiner ska hwila p mjuka tuvor.

sub new {
    my $class = shift;
    my $self = {
		title => shift,
		justify => "left",
		rawfonts => [],
		rawcolors => [],
		rawbody => ""
    };
    bless $self, $class;
    return $self;
}
sub rtf {
    my($self, @parameters) = @_;
	my $rtf=qq^{\\rtf1\\ansi\n^;
	$rtf.="{\\fonttbl".join("\n",@{$self->{rawfonts}})."}\n" if( $#{$self->{rawfonts}}>=0 );
	$rtf.="{\\colortbl;".join("",@{$self->{rawcolors}})."}\n" if( $#{$self->{rawcolors}}>=0 );
	$rtf.=qq^{\\*\\generator PERL-RTF (www.jojoxx.net) 1.0.0.0001;}\\pard \n^;
	$rtf.=$self->{rawbody}."}";
	return $rtf;
}
sub setstyle {
    my($self, @parameters) = @_;
	$self->{rawbody}.="\\i " if($_[1] eq 'italic');
	$self->{rawbody}.="\\b " if($_[1] eq 'bold');
#	$self->{rawbody}.="\\i0 \\b0 " if($_[1] eq 'normal');
	$self->{rawbody}.="\\plain " if($_[1] eq 'normal');
}
sub justify {
    my($self, @parameters) = @_;
	if($_[1]){
		$self->{rawbody}.="\\par " if($_[1] ne $self->{justify});
		$self->{rawbody}.="\\ql " if($_[1] eq 'left');
		$self->{rawbody}.="\\qc " if($_[1] eq 'center');
		$self->{rawbody}.="\\qr " if($_[1] eq 'right');
	} else {
		return $self->{justify};
	}
}
sub setcolor {
    my($self, @parameters) = @_;
	$self->{rawbody}.="\\cf$_[1] ";
}
sub setfont {
    my($self, @parameters) = @_;
	$self->{rawbody}.="\\f$_[1] ";
}
sub setfontsize {
    my($self, @parameters) = @_;
	my $size=int($_[1]*2);
	$self->{rawbody}.="\\fs$size ";
}
sub addtext {
    my($self, @parameters) = @_;
	$self->{rawbody}.=escape($_[1]);
}
sub addparagraf {
    my($self, @parameters) = @_;
	$self->{rawbody}.=escape($_[1])."\\par\n";
}
sub definefont {
    my($self, @parameters) = @_;
	my $fontnumber=$#{$self->{rawfonts}}+1;
	my $fontname=$_[1]; my $fontfamily=($_[2])?lc($_[2]):"roman";
	push(@{$self->{rawfonts}},qq^{\\f$fontnumber\\f$fontfamily\\fcharset0 $fontname;}^);
	return $fontnumber;
}
sub definecolor {
    my($self, @parameters) = @_;
	my $colornumber=$#{$self->{rawcolors}}+2;
	my @rgb=split(",",$_[1]);
	push(@{$self->{rawcolors}},qq^\\red$rgb[0]\\green$rgb[1]\\blue$rgb[2];^);
	return $colornumber;
}
sub save {
    my($self, @parameters) = @_;
	open(OUT,">$_[1]"); print OUT $self->rtf; close(OUT);
	return (-f "$_[1]");
}
sub escape {
	my $str=$_[0];
	$str=~s/\\/\\\\/g;
	$str=~s/\{/\\\{/g;
	$str=~s/\}/\\\}/g;
	return $str;
}
1;

__END__

=head1 NAME

RTF - Rich Text Format Writer

=head1 SYNOPSIS

 use jj::rtf;
 
 $mydoc=jj::rtf->new();
 $red=$mydoc->definecolor("255,0,0");
 $times=$mydoc->definefont("Times New Roman","roman");
 $arial=$mydoc->definefont("Arial","swiss");
 $mydoc->addparagraf("Some text.");
 $mydoc->setcolor($red);
 $mydoc->addparagraf("Some red text.");
 $mydoc->setfont($arial);
 $mydoc->addparagraf("Some text in Arial.");
 $mydoc->save("doc.rtf");
 
=head1 DESCRIPTION

RTF example
---
{\rtf1\ansi
{\fonttbl{\f0\froman\fcharset0 Times New Roman;}
{\f1\fswiss\fcharset0 Arial;}}
{\colortbl;\red255\green0\blue0;}
{\*\generator PERL-RTF (www.jojoxx.net) 1.0.0.0001;}\pard\f0\fs30 
Some text\par
\cf1 Some red text\par
\f1 Some text in Arial\par
}
---

